%global version 1.2.8
%global rpmrelease 0.6.beta

%global distname squirrelmail.imap_proxy

# location of SSL certificate
%global _pki_dir %{_sysconfdir}/pki/%{name}
%global _ssl_pem_file %{_pki_dir}/%{name}.pem

# systemd options
%global _has_systemd %(eval rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  %global _servicefile_postfix %{_has_systemd}.service
%else
  %global _servicefile_postfix init
%endif

Summary: Imapproxy is a proxy for the IMAP protocol
Name: imapproxy
Version: %{version}
Release: %{rpmrelease}%{?dist}
License: GPLv2+
Group: System Environment/Daemons
URL: http://www.imapproxy.org/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: http://snapshots.squirrelmail.org/squirrelmail-20200421_0200-SVN.imap_proxy.tar.bz2
Source1: %{name}.%{_servicefile_postfix}
Source2: http://ftp.de.debian.org/debian/pool/main/u/up-imapproxy/up-imapproxy_1.2.8~svn20171105-2.debian.tar.gz
Patch0: imapproxy-conf.patch
Patch1: imapproxy-pgm_name.patch
%if %{_has_systemd}
Patch2: imapproxy-systemd.patch
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
Requires(pre): %{_sbindir}/groupadd, %{_sbindir}/useradd
Requires(post): openssl, coreutils
BuildRequires: openssl-devel, pkgconfig, sed, %{__perl}
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
Imapproxy proxies IMAP transactions between an IMAP client and an IMAP server. The
general idea is that the client should never know that it's not talking to the real
IMAP server. The only thing that makes this a slightly unique Imap Proxy server is
that it caches server connections.

%prep
%setup -q -n %{distname} -a 2
%patch0 -p1 -b .conf
%patch1 -p1 -b .pgm_name
%if %{_has_systemd}
%patch2 -p1 -b .systemd_rundir
%endif

for i in debian/patches/fix-*.patch debian/patches/openssl-*.patch; do
  %{__patch} -p1 < $i
done

%build
export CFLAGS="%{optflags}"
if pkg-config openssl; then
  CPPFLAGS="$(pkg-config --cflags-only-I openssl) $CPPFLAGS"; export CPPFLAGS
  CFLAGS="$(pkg-config --cflags openssl) $CFLAGS"; export CFLAGS
  LDFLAGS="$(pkg-config --libs-only-L openssl) $LDFLAGS"; export LDFLAGS
fi
%configure
%{__make}

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sbindir}
%{__install} -d %{buildroot}%{_sysconfdir}
%{__install} -d %{buildroot}%{_pki_dir}
%{__install} -d %{buildroot}%{_mandir}/man8
%{__install} -d %{buildroot}%{_var}/empty/%{name}
%{__install} -d %{buildroot}%{_var}/log

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0755 -p bin/in.imapproxyd %{buildroot}%{_sbindir}/%{name}
%{__install} -m 0755 -p bin/pimpstat %{buildroot}%{_sbindir}/
%{__install} -m 0644 -p scripts/%{name}.conf %{buildroot}%{_sysconfdir}/

# install manpages
%{__sed} -e "s|imapproxyd|imapproxy|g" debian/manpages/imapproxyd.8 > %{buildroot}%{_mandir}/man8/%{name}.8
%{__sed} -e "s|imapproxyd|imapproxy|g" debian/manpages/pimpstat.8 > %{buildroot}%{_mandir}/man8/pimpstat.8

# create ghost pem file
touch %{buildroot}%{_ssl_pem_file}

# create ghost log file
touch %{buildroot}%{_var}/log/%{name}_protocol.log

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{name} > /dev/null || %{_sbindir}/groupadd -r %{name} 2> /dev/null || :
getent passwd %{name} > /dev/null || \
  %{_sbindir}/useradd -g %{name} -s /sbin/nologin -r -c "IMAP Proxy Server" -d %{_var}/empty/%{name} %{name} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

# create self-signed SSL certificate
if [ ! -f %{_ssl_pem_file} ]; then
  umask 0077
  CERTPARAMS="--\nSomeState\nSomeCity\nSomeOrganization\nSomeOrganizationalUnit\n$(hostname)\nroot@$(hostname)"
  CERT=$(mktemp /tmp/cert.XXXXXXXX)
  KEY=$(mktemp /tmp/key.XXXXXXXX)
  echo -e "$CERTPARAMS" |
    openssl req -newkey rsa:2048 -x509 -nodes -days 3653 -set_serial $RANDOM -out $CERT -keyout $KEY > /dev/null 2>&1
  RETVAL=$?
  if [ $RETVAL -eq 0 ]; then
    {
      %{__cat} $CERT
      echo ""
      %{__cat} $KEY
    } > %{_ssl_pem_file}
    %{__chmod} 0640 %{_ssl_pem_file}
    %{__chown} root.%{name} %{_ssl_pem_file}
  fi
  %{__rm} -f $CERT $KEY
fi
exit 0

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc COPYING copyright ChangeLog README README.ssl README.known_issues
%doc debian/additions/FAQ.txt
%{_sbindir}/%{name}
%{_sbindir}/pimpstat
%config(noreplace) %{_sysconfdir}/%{name}.conf
%if %{_has_systemd}
%{_unitdir}/%{name}.service
%else
%config %{_initrddir}/%{name}
%endif
%{_mandir}/man8/*.8*
%attr(0711,root,root) %dir %{_var}/empty/%{name}
%dir %{_pki_dir}
%attr(0640,root,%{name}) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{_ssl_pem_file}
%attr(0600,%{name},%{name}) %ghost %verify(not md5 size mtime) %{_var}/log/%{name}_protocol.log

%changelog
* Wed Jan 12 2022 Simon Matter <simon.matter@invoca.ch> 1.2.8-0.6.beta
- cosmetic spec changes

* Tue Jan 11 2022 Simon Matter <simon.matter@invoca.ch> 1.2.8-0.5.beta
- add support for EL9

* Thu Feb 25 2021 Simon Matter <simon.matter@invoca.ch> 1.2.8-0.4.beta
- fix creation of pem file on EL8

* Mon Jan 11 2021 Simon Matter <simon.matter@invoca.ch> 1.2.8-0.3.beta
- run as user imapproxy

* Thu Apr 23 2020 Simon Matter <simon.matter@invoca.ch> 1.2.8-0.2.beta
- clean up default config

* Tue Apr 21 2020 Simon Matter <simon.matter@invoca.ch> 1.2.8-0.1.beta
- upgrade to 1.2.8-SVN
- add support for EL8

* Tue May 26 2015 Simon Matter <simon.matter@invoca.ch> 1.2.7-5
- fix pki location for EL7

* Sat May 23 2015 Simon Matter <simon.matter@invoca.ch> 1.2.7-4
- add support for systemd

* Thu Jan 03 2013 Simon Matter <simon.matter@invoca.ch> 1.2.7-3
- add FAQ.txt from debian

* Thu Jan 03 2013 Simon Matter <simon.matter@invoca.ch> 1.2.7-2
- rename in.imapproxyd to imapproxy
- add chroot config
- add manpages from debian

* Wed Jan 02 2013 Simon Matter <simon.matter@invoca.ch> 1.2.7-1
- initial build
